@@ -5,6 +5,13 @@ class _Node:
         self.next = next
 
 
+def change(node1, node2):
+    bid = node1.data
+    node1.data = node2.data
+    node2.data = bid
+    del bid
+
+
 class List:
     def __init__(self):
         self.__head = None
@@ -150,7 +157,19 @@ class List:
             prv = cur
             cur = nxt
         self.__head = prv
-    
+ 
+    def sort(self):
+        tmp1 = self.__head
+        tmp2 = tmp1.next
+        while tmp1.next is not None:
+            while tmp2 is not None:
+                if tmp1.data > tmp2.data:
+                    change(tmp1, tmp2)
+                tmp2 = tmp2.next
+            tmp1 = tmp1.next
+            tmp2 = tmp1.next
+        del tmp1, tmp2
+       
     def exchange(self, n):
         for i in range(n):
             self.append(self.remove())
