@@ -5,6 +5,13 @@ class _Node:
         self.next = next
 
 
+def change(node1, node2):
+    bid = node1.data
+    node1.data = node2.data
+    node2.data = bid
+    del bid
+
+
 class Stack:
     def __init__(self):
         self.__top = None
@@ -68,7 +75,19 @@ class Stack:
         while not self.empty():
             stck.push(self.pop())
         return stck
-    
+
+    def sort(self):
+        tmp1 = self.__top
+        tmp2 = tmp1.next
+        while tmp1.next is not None:
+            while tmp2 is not None:
+                if tmp1.data > tmp2.data:
+                    change(tmp1, tmp2)
+                tmp2 = tmp2.next
+            tmp1 = tmp1.next
+            tmp2 = tmp1.next
+        del tmp1, tmp2
+
     def exchange(self, n):
         bid1 = Stack()
         bid2 = Stack()
@@ -110,4 +129,4 @@ class Stack:
             s2.push(bid1.pop())
         while not bid2.empty():
             s1.push(bid2.pop())
-        del bid1, bid2
\ No newline at end of file
+        del bid1, bid2
